/*
 * Title:        GridSim Toolkit
 * Description:  GridSim (Grid Simulation) Toolkit for Modeling and Simulation
 *               of Parallel and Distributed Systems such as Clusters and Grids
 * Licence:      GPL - http://www.gnu.org/copyleft/gpl.html
 *
 * $Id: ResGridletList.java,v 1.8 2004/05/19 02:38:00 anthony Exp $
 */

package gridsim;

import java.util.LinkedList;


/**
 * GridSim ResGridletList maintains a linked-list of Gridlet
 *
 * @author       Manzur Murshed and Rajkumar Buyya
 * @version      3.0, May 2004
 * @since        GridSim Toolkit 1.0
 * @invariant $none
 */
public class ResGridletList extends LinkedList
{
    /**
     * Allocates a new ResGridletList object
     * @pre $none
     * @post $none
     */
    public ResGridletList() {
        super();
    }

    /**
     * Move a ResGridlet object from this linked-list into a specified one
     * @param obj a ResGridlet object to be moved
     * @param list a ResGridletList object to store the new ResGridlet object
     * @return <b>true</b> if the moving operation successful,
     *         otherwise return <b>false</b>
     * @pre obj != null
     * @pre list != null
     * @post $result == true || $result == false
     */
    public boolean move(ResGridlet obj, ResGridletList list)
    {
        boolean success = false;
        if (super.remove(obj) == true)
        {
            list.add(obj);
            success = true;
        }

        return success;
    }

} // end class
